execute

Function execute 

pub fn execute(
    plan: &LogicalPlan,
    store: &RocksDbStorageEngine,
) -> Result<Vec<Row>>
Execute a plan using the given store for both reads and writes. Equivalent to execute_with_reader with the store acting as both and an empty parameter map.